from setuptools import setup

setup(
    name='webpigpio',
    version='0.1.0',
    packages=['webpigpio'],
    author='Sachin Patney',
    license='MIT',
    url='https://github.com/sachinio/pilibs/tree/master/src/webpigpio',
    description='Command GPIO via options bag, used for a web driven gpio contoller for raspberry pi'
)
